@@ -12,7 +12,7 @@ import utm
 import pyproj
 from aenum import extend_enum
 
-from .exceptions import SHDeprecationWarning, SHUserWarning
+from .exceptions import SHUserWarning
 from ._version import __version__
 
 
@@ -342,6 +342,19 @@ class MimeType(Enum):
         :return: A mime type enum
         :rtype: MimeType
         """
+
+        # These two cases are handled seperately due to issues with python 3.6
+        if mime_type_str == 'image/jpeg':
+            return MimeType.JPG
+        if mime_type_str == 'text/plain':
+            return MimeType.TXT
+
+        guessed_extension = mimetypes.guess_extension(mime_type_str)
+        if guessed_extension:
+            mime_type_str = guessed_extension.strip('.')
+        else:
+            mime_type_str = mime_type_str.split('/')[-1]
+
         if MimeType.has_value(mime_type_str):
             return MimeType(mime_type_str)
 
@@ -349,20 +362,11 @@ class MimeType(Enum):
             return {
                 'tif': MimeType.TIFF,
                 'jpeg': MimeType.JPG,
-                'jpg': MimeType.JPG,
                 'hdf5': MimeType.HDF,
                 'h5': MimeType.HDF
             }[mime_type_str]
         except KeyError as exception:
-            raise ValueError(f'Data format .{mime_type_str} is not supported') from exception
-
-    @staticmethod
-    def canonical_extension(fmt_ext):
-        """ A deprecated method, use MimeType.from_string().extension instead
-        """
-        warnings.warn('This method is deprecated and will soon be removed, use MimeType.from_string().extension '
-                      'instead', category=SHDeprecationWarning)
-        return MimeType.from_string(fmt_ext).extension
+            raise ValueError(f'Data format {mime_type_str} is not supported') from exception
 
     def is_image_format(self):
         """ Checks whether file format is an image format
@@ -407,6 +411,8 @@ class MimeType(Enum):
             return 'application/json'
         if self is MimeType.JP2:
             return 'image/jpeg2000'
+        if self is MimeType.XML:
+            return 'text/xml'
         if self is MimeType.RAW:
             return self.value
         return mimetypes.types_map['.' + self.value]
